"use strict";

exports.__esModule = true;
var _exportNames = {
  withDashboard: true,
  PageLink: true,
  useDashboard: true,
  useWidget: true,
  useContainerWidgets: true,
  useContainerMenuItems: true,
  usePageLocation: true,
  useLanguage: true
};
exports.withDashboard = exports.useWidget = exports.usePageLocation = exports.useLanguage = exports.useDashboard = exports.useContainerWidgets = exports.useContainerMenuItems = exports.PageLink = void 0;
var _react = require("react");
var _sdkReact = require("@wix/sdk-react");
var _dashboard = require("@wix/dashboard");
Object.keys(_dashboard).forEach(function (key) {
  if (key === "default" || key === "__esModule") return;
  if (Object.prototype.hasOwnProperty.call(_exportNames, key)) return;
  if (key in exports && exports[key] === _dashboard[key]) return;
  exports[key] = _dashboard[key];
});
var _withDashboard = require("./withDashboard");
exports.withDashboard = _withDashboard.withDashboard;
var _PageLink = require("./PageLink");
exports.PageLink = _PageLink.PageLink;
// eslint-disable-next-line import/no-extraneous-dependencies

// eslint-disable-next-line import/no-extraneous-dependencies

/**
 * Returns an object with methods to interact with the dashboard.
 */
const useDashboard = () => {
  const sdk = (0, _sdkReact.useWixModules)(_dashboard.dashboard);
  return (0, _react.useMemo)(() => {
    return {
      showToast: sdk.showToast,
      navigate: sdk.navigate,
      navigateBack: sdk.navigateBack,
      openModal: sdk.openModal,
      closeModal: sdk.closeModal,
      getAccessToken: sdk.getAccessToken,
      getPageUrl: sdk.getPageUrl,
      setPageTitle: sdk.setPageTitle,
      openMediaManager: sdk.openMediaManager,
      addSitePlugin: sdk.addSitePlugin,
      onBeforeUnload: sdk.onBeforeUnload,
      requestFeedback: sdk.requestFeedback,
      onLayerStateChange: sdk.onLayerStateChange
    };
  }, [sdk]);
};
exports.useDashboard = useDashboard;
const useWidget = (componentId, options) => {
  const channel = useHostChannelDirectly();
  return channel.useWidget(componentId, options);
};
exports.useWidget = useWidget;
const useContainerWidgets = (componentId, options) => {
  const channel = useHostChannelDirectly();
  return channel.useContainerWidgets(componentId, options);
};
exports.useContainerWidgets = useContainerWidgets;
const useContainerMenuItems = (componentId, options) => {
  const channel = useHostChannelDirectly();
  return channel.useContainerMenuItems(componentId, options);
};
exports.useContainerMenuItems = useContainerMenuItems;
const useHostChannelDirectly = () => {
  const reactDashboardModule = {
    /*
    Creating custom react module, so we can access host api.
    These methods don't exist in vanilla dashboard sdk, so we need a custom module to extract them from the host prop passes to apps.
    */
    __type: 'host',
    create: host => host.channel
  };
  return (0, _sdkReact.useWixModules)(reactDashboardModule);
};
const usePageLocation = () => {
  const environment = (0, _sdkReact.useEnvironment)();
  const {
    pageId,
    pathname,
    search,
    hash
  } = environment.pageLocation;
  return (0, _react.useMemo)(() => ({
    pageId,
    pathname,
    search,
    hash
  }), [pageId, pathname, search, hash]);
};
exports.usePageLocation = usePageLocation;
const useLanguage = () => {
  const {
    language
  } = (0, _sdkReact.useEnvironment)();
  return language;
};
exports.useLanguage = useLanguage;
//# sourceMappingURL=react.js.map