// eslint-disable-next-line import/no-extraneous-dependencies
import { useMemo } from 'react';
// eslint-disable-next-line import/no-extraneous-dependencies
import { useWixModules, useEnvironment } from '@wix/sdk-react';
import { dashboard } from '@wix/dashboard';
export * from '@wix/dashboard';
export { withDashboard } from './withDashboard';
export { PageLink } from './PageLink';

/**
 * Returns an object with methods to interact with the dashboard.
 */
export const useDashboard = () => {
  const sdk = useWixModules(dashboard);
  return useMemo(() => {
    return {
      showToast: sdk.showToast,
      navigate: sdk.navigate,
      navigateBack: sdk.navigateBack,
      openModal: sdk.openModal,
      closeModal: sdk.closeModal,
      getAccessToken: sdk.getAccessToken,
      getPageUrl: sdk.getPageUrl,
      setPageTitle: sdk.setPageTitle,
      openMediaManager: sdk.openMediaManager,
      addSitePlugin: sdk.addSitePlugin,
      onBeforeUnload: sdk.onBeforeUnload,
      requestFeedback: sdk.requestFeedback,
      onLayerStateChange: sdk.onLayerStateChange
    };
  }, [sdk]);
};
export const useWidget = (componentId, options) => {
  const channel = useHostChannelDirectly();
  return channel.useWidget(componentId, options);
};
export const useContainerWidgets = (componentId, options) => {
  const channel = useHostChannelDirectly();
  return channel.useContainerWidgets(componentId, options);
};
export const useContainerMenuItems = (componentId, options) => {
  const channel = useHostChannelDirectly();
  return channel.useContainerMenuItems(componentId, options);
};
const useHostChannelDirectly = () => {
  const reactDashboardModule = {
    /*
    Creating custom react module, so we can access host api.
    These methods don't exist in vanilla dashboard sdk, so we need a custom module to extract them from the host prop passes to apps.
    */
    __type: 'host',
    create: host => host.channel
  };
  return useWixModules(reactDashboardModule);
};
export const usePageLocation = () => {
  const environment = useEnvironment();
  const {
    pageId,
    pathname,
    search,
    hash
  } = environment.pageLocation;
  return useMemo(() => ({
    pageId,
    pathname,
    search,
    hash
  }), [pageId, pathname, search, hash]);
};
export const useLanguage = () => {
  const {
    language
  } = useEnvironment();
  return language;
};
//# sourceMappingURL=react.js.map